[PATCH] D112593: [AIX] Disable cfi-version test on AIX

Jake Egan via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Sun Oct 31 06:33:36 PDT 2021


This revision was landed with ongoing or failed builds.
This revision was automatically updated to reflect the committed changes.
Closed by commit rGfa1dd5fdeee2: [AIX] Disable cfi-version test on AIX (authored by Jake-Egan).

Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D112593/new/

https://reviews.llvm.org/D112593

Files:
  llvm/test/MC/ELF/cfi-version.ll
  llvm/test/lit.cfg.py


Index: llvm/test/MC/ELF/cfi-version.ll
===================================================================
--- llvm/test/MC/ELF/cfi-version.ll
+++ llvm/test/MC/ELF/cfi-version.ll
@@ -6,7 +6,7 @@
 ; PR46647
 ; XFAIL: arm64-apple
 
-; .debug_frame is not emitted for targeting Windows x64 or arm64.
+; .debug_frame is not emitted for targeting Windows x64, arm64, or AIX.
 ; REQUIRES: debug_frame
 ; REQUIRES: default_triple
 


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D112593.383648.patch
Type: text/x-patch
Size: 1104 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20211031/9dafdce5/attachment.bin>


More information about the llvm-commits mailing list
Index: llvm/test/lit.cfg.py
===================================================================
--- llvm/test/lit.cfg.py
+++ llvm/test/lit.cfg.py
@@ -381,8 +381,8 @@
         if 'hw.optional.fma: 1' in result:
             config.available_features.add('fma3')
 
-# .debug_frame is not emitted for targeting Windows x64 or arm64.
-if not re.match(r'^(x86_64|arm64).*-(windows-gnu|windows-msvc)', config.target_triple):
+# .debug_frame is not emitted for targeting Windows x64, arm64, or AIX.
+if not re.match(r'^(x86_64|arm64|powerpc|powerpc64).*-(windows-gnu|windows-msvc|aix)', config.target_triple):
     config.available_features.add('debug_frame')
 
 if config.have_libxar: